/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: BUSL-1.1
 */

export { breadcrumbsForSecret as default } from 'kv/utils/kv-breadcrumbs';
